# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from cohesivenet.api_builder import VersionRouter


def get_clientpack(api_client, clientpack_name, **kwargs):  # noqa: E501
    """get_clientpack  # noqa: E501

    Returns detailed information about all of the clientpacks in the topology.
    If controllers's are properly peered, this information can come from any of the controllers.   # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_clientpack(client, clientpack_name, async_req=True)

    :param async_req bool: execute request asynchronously
    :param str clientpack_name: name of clientpack (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"clientpack_name": clientpack_name}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpacks/{clientpack_name}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_clientpacks(api_client, sorted=None, **kwargs):  # noqa: E501
    """get_clientpacks  # noqa: E501

    Returns detailed information about all of the clientpacks in the topology.
    If controllers's are properly peered, this information can come from any of the controllers.  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_clientpacks(client, async_req=True)

    :param async_req bool: execute request asynchronously
    :param bool sorted: Sort resources
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["sorted"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpacks",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_clients_status(api_client, **kwargs):  # noqa: E501
    """get_clients_status  # noqa: E501

    Describe overlay clients  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_clients_status(client, async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/status/clients",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_connected_subnets(api_client, extended_output=None, **kwargs):  # noqa: E501
    """get_connected_subnets  # noqa: E501

    Provides information about any connected subnets.  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_connected_subnets(async_req=True)

    :param async_req bool: execute request asynchronously
    :param bool extended_output: Receive verbose information about resources
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["extended_output"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/status/connected_subnets",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_download_clientpack(
    api_client, name=None, fileformat=None, format=None, **kwargs
):  # noqa: E501
    """get_download_clientpack  # noqa: E501

    Returns clientpack file. Clientpacks are files with the necessary information and credentials  for an overlay client to be connected to the VNS3 topology   # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_download_clientpack(client, name="100.171.10.1", format="conf", async_req=True)

    :param async_req bool: execute request asynchronously
    :param name str: name of clientpack
    :param fileformat str: format for file (ovpn, conf, zip or tarball)
    :param format str: format for file (ovpn, conf, zip or tarball) (alias for fileformat)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["name", "fileformat", "format"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["text/plain", "application/octet-stream"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpack",
        "GET",
        path_params,
        query_params,
        header_params,
        body={},
        post_params=form_params,
        files=local_var_files,
        response_type="file:%s" % local_var_params["fileformat"],
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_checkout_next_clientpack(
    api_client, low_ip=None, high_ip=None, include_disabled=None, **kwargs
):  # noqa: E501
    """post_checkout_next_clientpack  # noqa: E501

    Get next sequential client pack. Provides sufficient information to call GET /clientpack.
    Note, Using this resource against multiple controllers in the same topology could cause distribution of the
    same clientpack to multiple overlay devices which is not allowed.   # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_checkout_next_clientpack(client, async_req=True)

    :param low_ip str: Set the lower bound for the resulting IP
    :param high_ip str: Set the upper bound for the resulting IP
    :param include_disabled bool: Allows clientpack allocation from the disabled pool, for workflows where all clientpacks are disabled at the start.
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["low_ip", "high_ip", "include_disabled"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpacks/next_available",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_clientpack_tag(
    api_client, clientpack_name, key=None, value=None, **kwargs
):  # noqa: E501
    """post_create_clientpack_tag  # noqa: E501

    For tagging individual clientpacks.  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_clientpack_tag(clientpack_name, create_clientpack_tag_request, async_req=True)

    :param async_req bool: execute request asynchronously
    :param str clientpack_name: name of clientpack (required)
    :param str key: (required)
    :param str value: (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["key", "value"]  # noqa: E501

    collection_formats = {}

    path_params = {"clientpack_name": clientpack_name}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpack/{clientpack_name}",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_clientpack_tag(
    api_client, clientpack_name, key=None, **kwargs
):  # noqa: E501
    """delete_clientpack_tag  # noqa: E501

    For deleting individual clientpack tags  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_clientpack_tag(clientpack_name, clientpack_tag_key_request, async_req=True)

    :param str clientpack_name: name of clientpack (required)
    :param str key: (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["key"]  # noqa: E501

    collection_formats = {}

    path_params = {"clientpack_name": clientpack_name}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpack/{clientpack_name}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_reset_all_clients(api_client, **kwargs):  # noqa: E501
    """post_reset_all_clients  # noqa: E501

    For resetting all of the connections of clients connected to the VNS3 Controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_reset_all_clients(async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clients/reset_all",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_reset_client(api_client, name=None, disconnect=True, **kwargs):  # noqa: E501
    """post_reset_client  # noqa: E501

    For resetting the connection of a client to a VNS3 Controller  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_reset_client(reset_overlay_client_request, async_req=True)

    :param async_req bool: execute request asynchronously
    :param name str: name of clientpack (required)
    :param disconnect bool: true to disconnect
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["name", "disconnect"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/client/reset",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_add_clientpacks(api_client, requested_ips=None, **kwargs):  # noqa: E501
    """put_add_clientpacks  # noqa: E501

    Incrementally add new clientpacks for use  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_add_clientpacks(client, requested_ips=requested_ips, async_req=True)

    :param requested_ips str: CSV of IP addresses to be used for new clientpacks (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["requested_ips"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpacks/add_clientpacks",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


# TODO one of checked_out regenerated enabled
def put_update_clientpack(
    api_client, name=None, enabled=None, checked_out=None, regenerate=None, **kwargs
):  # noqa: E501
    """put_clientpack  # noqa: E501

    Change properties of clientpacks; enabling or disabling, checking in or out, or regenerating  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_clientpack(client, name, checked_out=True,async_req=True)

    :param name str: name of clientpack (required)
    :param enabled bool: Enable or disable clientpacks.
    :param checked_out bool: Update whether clientpacks are checked out and thus unavailable
    :param regenerate bool: Regenerate this clientpack
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["name", "enabled", "checked_out", "regenerate"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpack",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_disconnect_clientpack(
    api_client, clientpack_name, disconnect=True, **kwargs
):  # noqa: E501
    """put_disconnect_clientpack  # noqa: E501

    Force disconnect client for named clientpack  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_disconnect_clientpack(client, clientpack_name, disconnect=True, async_req=True)

    :param async_req bool: execute request asynchronously
    :param str clientpack_name: name of clientpack (required)
    :param disconnect bool: (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["disconnect"]  # noqa: E501

    collection_formats = {}

    path_params = {"clientpack_name": clientpack_name}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpack/{clientpack_name}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_all_clientpacks(
    api_client, enabled=None, checked_out=None, **kwargs
):  # noqa: E501
    """put_update_clientpacks  # noqa: E501

    For bulk set of the enabled (true/false) state for all clientpacks and the checked_out (true/false) state for all clientpacks.  This enables a variety of work flows by calling these functions after key generation,  but before general provisioning of addresses to devivces   # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_clientpacks(update_config_clientpack_request, async_req=True)

    :param enabled bool: Enable all clientpacks
    :param checked_out bool: Mark all clientpacks checked out
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["enabled", "checked_out"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/clientpacks",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


class OverlayNetworkApiRouter(VersionRouter):
    # put_update_clientpacks
    function_library = {
        "delete_clientpack_tag": {"4.8.4-4.10.1": delete_clientpack_tag},
        "get_clientpack": {"4.8.4-4.10.1": get_clientpack},
        "get_clientpacks": {"4.8.4-4.10.1": get_clientpacks},
        "get_clients_status": {"4.8.4-4.10.1": get_clients_status},
        "get_connected_subnets": {"4.8.4-4.10.1": get_connected_subnets},
        "get_download_clientpack": {"4.8.4-4.10.1": get_download_clientpack},
        "post_checkout_next_clientpack": {
            "4.8.4-4.10.1": post_checkout_next_clientpack
        },
        "post_create_clientpack_tag": {"4.8.4-4.10.1": post_create_clientpack_tag},
        "post_reset_all_clients": {"4.8.4-4.10.1": post_reset_all_clients},
        "post_reset_client": {"4.8.4-4.10.1": post_reset_client},
        "post_add_clientpacks": {"4.8.4-4.10.1": post_add_clientpacks},
        "put_update_clientpack": {"4.8.4-4.10.1": put_update_clientpack},
        "put_disconnect_clientpack": {"4.8.4-4.10.1": put_disconnect_clientpack},
        "put_update_all_clientpacks": {"4.8.4-4.10.1": put_update_all_clientpacks},
    }



from __future__ import absolute_import

import pytest

from tests.rest_mock import RestClientMock

import cohesivenet
import cohesivenet.api.vns3ms as vns3ms_api
from cohesivenet import MSClient, Configuration, LATEST_VNS3_MS_VERSION
from cohesivenet.rest import ApiException


class TestVNS3Client(object):
    """Test VNS3ms API client"""

    def test_api_properties(self):
        """Test all API groups are accessible as properties
        """
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0", username="api", api_key="abcdefge", verify_ssl=False,
            )
        )

        assert hasattr(api_client, "access")
        assert type(api_client.access) is vns3ms_api.AccessApi
        assert hasattr(api_client, "admin")
        assert type(api_client.admin) is vns3ms_api.AdministrationApi
        assert hasattr(api_client, "backups")
        assert type(api_client.backups) is vns3ms_api.BackupsApi
        assert hasattr(api_client, "cloud_monitoring")
        assert type(api_client.cloud_monitoring) is vns3ms_api.CloudMonitoringApi
        assert hasattr(api_client, "system")
        assert type(api_client.system) is vns3ms_api.SystemApi
        assert hasattr(api_client, "user")
        assert type(api_client.user) is vns3ms_api.UserApi
        assert hasattr(api_client, "vns3_management")
        assert type(api_client.vns3_management) is vns3ms_api.VNS3ManagementApi

    def test_get_client_state(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                api_key="abcdefge",
                verify_ssl=False,
            )
        )

        state = api_client.state
        assert type(state) is dict
        assert len(state) == 0

    def test_get_latest_available_version(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                api_key="abcdefge",
                verify_ssl=False,
            )
        )

        latest_version = api_client.latest_version()
        assert LATEST_VNS3_MS_VERSION == latest_version

    def test_add_client_state(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                api_key="abcdefge",
                verify_ssl=False,
            )
        )

        api_client.add_to_state("private_ip", "10.0.24.30")
        state = api_client.state
        assert "private_ip" in state and state["private_ip"] == "10.0.24.30"
        assert len(state) == 1

    def test_update_client_state(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0", username="api", api_key="abcdefge", verify_ssl=False,
            )
        )

        updates = {
            "topology_container_network": "192.169.16.0/24",
            "subnet": "10.0.2.0/24",
        }
        api_client.update_state(updates)
        state = api_client.state
        assert set(updates.keys()).issubset(set(state.keys()))
        assert state["subnet"] == updates["subnet"]
        assert len(state) == 2

    def test_query_state(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0", username="api", api_key="abcdefge", verify_ssl=False,
            )
        )

        test_value = 12312
        updates = {
            "container_network": "192.169.16.0/28",
            "subnet": "10.0.2.0/24",
            "test_key": test_value,
        }

        api_client.update_state(updates)
        assert api_client.query_state("test_key") == test_value

    def test_host_uri_property(self):
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0:443",
                username="api",
                api_key="abcdefge",
                verify_ssl=False,
            )
        )
        assert api_client.host_uri == "0.0.0.0"

    def test_api_version_routing(self):
        """Test api_builder.VersionRouter inits class based on class correctly
        """
        api_client = MSClient(
            configuration=Configuration(
                host="0.0.0.0", username="api", password="password", verify_ssl=False,
            )
        )

        api_client.ms_version = "2.1.1"
        expected_api_methods = [
            "put_activate_api_key",
            "post_create_token",
            "put_expire_token",
            "put_invalidate_api_key_tokens",
            "get_api_keys",
            "post_create_api_key",
            "put_update_api_key",
            "delete_api_key",
        ]

        access_api = api_client.access
        for method_name in expected_api_methods:
            assert hasattr(access_api, method_name), (
                "Missing method %s on access_api" % method_name
            )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import datetime
import pytest

import cohesivenet
from cohesivenet.api.vns3 import monitoring_alerting_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import MonitoringApiData


class TestMonitoringAlertingApi(object):
    """MonitoringAlertingApi unit test stubs"""

    def test_delete_alert(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_alert
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertDetail,
        )(monitoring_alerting_api.delete_alert)

    def test_get_alert(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_alert
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertDetail,
        )(monitoring_alerting_api.get_alert)

    def test_get_alerts(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_alerts

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/alerts",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertsListResponse,
        )(monitoring_alerting_api.get_alerts)

    def test_post_create_alert(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for post_create_alert

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/alert",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertDetail,
        )(monitoring_alerting_api.post_create_alert)

    def test_post_test_alert(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for post_test_alert
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/alert/{alert_id}/test",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {"status": "success", "code": "200", "message": "OK"}
            },
        )(monitoring_alerting_api.post_test_alert)

    def test_post_toggle_enable_alert(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for post_toggle_enable_alert

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/alert/{alert_id}/toggle_enabled",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertDetail,
        )(monitoring_alerting_api.post_toggle_enable_alert)

    def test_put_update_alert(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for put_update_alert

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.AlertDetail,
        )(monitoring_alerting_api.put_update_alert)

    def test_delete_webhook(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_webhook
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.WebhookDetail,
        )(monitoring_alerting_api.delete_webhook)

    def test_get_webhook(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_webhook
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.WebhookDetail,
        )(monitoring_alerting_api.get_webhook)

    def test_get_webhooks(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_webhooks
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/webhooks",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.WebhookListResponse,
        )(monitoring_alerting_api.get_webhooks)

    def test_post_create_webhook(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for post_create_webhook
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/webhook",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.WebhookDetail,
        )(monitoring_alerting_api.post_create_webhook)

    def test_put_update_webhook(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for put_update_webhook

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=MonitoringApiData.WebhookDetail,
        )(monitoring_alerting_api.put_update_webhook)



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import vns3_management_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3ms.stub_data import Vns3ManagementApiData


class TestMSVNS3ManagementApi(object):
    """VNS3:ms VNS3 Management API unit tests"""

    def test_get_vns3_snapshots(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_vns3_snapshots
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/snapshots",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.Vns3SnapshotsList,
        )(vns3_management_api.get_vns3_snapshots)

    def test_post_create_vns3_snapshot(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_create_vns3_snapshot
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/snapshots",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response_type": "success", "response": "Snapshot created"},
        )(vns3_management_api.post_create_vns3_snapshot)

    def test_delete_vns3_snapshots(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_vns3_snapshots
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/snapshots",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.delete_vns3_snapshots)

    def test_get_download_vns3_snapshot(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_download_vns3_snapshot
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/snapshots/download",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response="imafileimafileimafileimafileimafileimafileimafile",
        )(vns3_management_api.get_download_vns3_snapshot)

    def test_get_controller_report(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_controller_report
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/controller_report",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.ControllerReport,
        )(vns3_management_api.get_controller_report)

    def test_get_vns3_controllers(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_vns3_controllers
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_controllers",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.Vns3ControllerList,
        )(vns3_management_api.get_vns3_controllers)

    def test_post_add_vns3_controller(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_add_vns3_controller
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/vns3_controllers",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.CreateVns3ControllerResponse,
        )(vns3_management_api.post_add_vns3_controller)

    def test_get_vns3_controller(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_vns3_controller
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_controllers/{vns3_controller_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.Vns3ControllerDetail,
        )(vns3_management_api.get_vns3_controller)

    def test_put_update_vns3_controller(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_vns3_controller
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_update_vns3_controller)

    def test_delete_vns3_controller(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_vns3_controller
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/vns3_controllers/{vns3_controller_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.delete_vns3_controller)

    def test_get_vns3_controller_status(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_vns3_controller_status
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_controllers/{vns3_controller_id}/status",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.get_vns3_controller_status)

    def test_put_vns3_controller_api_password(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_vns3_controller_api_password
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/update_api_password",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "API password updated",
            },
        )(vns3_management_api.put_vns3_controller_api_password)

    def test_put_vns3_controller_ui(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_vns3_controller_ui
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/update_ui",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "UI details updated",
            },
        )(vns3_management_api.put_vns3_controller_ui)

    def test_get_vns3_controller_ha_details(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_vns3_controller_ha_details
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_controllers/{vns3_controller_id}/ha",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=Vns3ManagementApiData.Vns3ControllerHaDetail,
        )(vns3_management_api.get_vns3_controller_ha_details)

    def test_put_update_vns3_controller_ha(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_vns3_controller_ha
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/ha",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_update_vns3_controller_ha)

    def test_put_validate_vns3_controller_ha(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_validate_vns3_controller_ha
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/ha/validate",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_validate_vns3_controller_ha)

    def test_put_init_vns3_controller_ha(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_init_vns3_controller_ha
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/ha/initialise",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_init_vns3_controller_ha)

    def test_put_sync_vns3_controller_ha(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_sync_vns3_controller_ha
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/ha/sync",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_sync_vns3_controller_ha)

    def test_put_activate_vns3_controller_ha(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_activate_vns3_controller_ha
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_controllers/{vns3_controller_id}/ha/activate",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.put_activate_vns3_controller_ha)

    def test_get_vns3_controller_ha_status(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_vns3_controller_ha_status
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_controllers/{vns3_controller_id}/ha/activate",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(vns3_management_api.get_vns3_controller_ha_status)



import typing

from functools import partial as bind

from cohesivenet import (
    data_types,
    network_math,
    Logger,
    util,
    VNS3Client,
    CohesiveSDKException,
)
from cohesivenet.macros import api_operations, state


VNS3Attr = state.VNS3Attr


def create_local_gateway_route(client, local_cidr, **route_kwargs):
    """[summary]

    Arguments:
        client {[type]} -- [description]
        local_cidr {[type]} -- [description]

    Keyword Arguments:
        gateway {[type]} -- [description] (default: {None})

    Returns:
        OperationResult
    """
    route = dict(
        **{
            "cidr": local_cidr,
            "description": "Local Underlay Network Routing",
            "interface": "eth0",
            "gateway": network_math.get_default_gateway(local_cidr),
            "advertise": "False",
            "metric": 0,
        },
        **route_kwargs
    )
    api_kwargs = {"should_raise": True}
    api_kwargs.update(route)
    return api_operations.try_call_api(client.routing.post_create_route, **api_kwargs)


def create_local_gateway_routes_for_peers(
    client: VNS3Client, local_network: str, peer_ips: typing.List[str]
):
    """Create route to local underlay gateway for IPs. This is commonly done for explicit routes
       to VNS3 peers.

    Arguments:
        client {VNS3Client}
        local_network {str} - local network cidr for VPC/VNET
        peer_ips {typing.List[str]}

    Returns:
        dict with list of routes.

        {
            response: [{
                cidr: "X.X.X.X/32",
                interface: "eth0",
            }, ...]
        }
    """
    routes = [
        {
            "cidr": ip if ip.endswith("/32") else "%s/32" % ip,
            "description": "Peer route to local gateway",
            "interface": "eth0",
            "gateway": network_math.get_default_gateway(local_network),
            "advertise": False,
        }
        for ip in peer_ips
    ]

    for route in routes:
        client.routing.post_create_route_if_not_exists(route)
    return client.routing.get_routes().json()


def create_peer_mesh_local_gw_routes(
    clients, subnets=None, address_type=VNS3Attr.primary_private_ip
):
    """Create explicit routes between VNS3 peers for peering traffic by pointing peer ips
    to the local gateway.

    For example, for clients = [VNS3@10.0.1.5, VNS3@10.0.2.10]
    in private clouds that are peered where 10.0.1.5 in 10.0.1.0/24 and
    10.0.2.10 in 10.0.2.0/24

    This func  will create the following routes:
        On VNS3@10.0.1.5:
            Route: cidr=10.0.2.10/32 on eth0 to network gateway at 10.0.1.1
        On VNS3@10.0.2.10:
            Route: cidr=10.0.1.5/32 on eth0 to network gateway at 10.0.2.1

    Assumptions:
        - IF subnets list not passed, Clients need to have the VPC/VNet network they are contained
        in set on their state.
            e.g. client.update_state({"network": "10.0.1.0/24"}); client.query_state("network");
            This function queries the following keys: network

    Arguments:
        clients {List[VNS3Client]}

    Keyword Arguments:
        subnets: List[str] - list of subnets for each client.
        address_type {str} -- Type of address to use for cidr route. (default: {VNS3Attr.primary_private_ip})
    """
    create_client_routes_funcs = []
    client_ips = [
        state.fetch_client_state_attribute(client, address_type) for client in clients
    ]

    if subnets:
        assert len(subnets) == len(
            clients
        ), "If subnets passed, must be same number of clients passed"

    for i, client in enumerate(clients):
        client_subnet_cidr = subnets[i] if subnets else client.query_state("subnet")
        client_ip = state.fetch_client_state_attribute(client, address_type)
        assert (
            client_subnet_cidr
        ), "Each client must have 'subnet' set on client.state if subnets arg not passed"
        create_client_routes_funcs.append(
            bind(
                create_local_gateway_routes_for_peers,
                client,
                client_subnet_cidr,
                list(set(client_ips) - set([client_ip])),
            )
        )

    return api_operations.__bulk_call_api(create_client_routes_funcs, parallelize=True)


def create_route_advertisements(
    clients, local_subnets
) -> data_types.BulkOperationResult:
    """create_route_advertisements Create a route advertisement for controllers network

    Arguments:
        clients {List[VNS3Client]}
        local_subnets {List[str]} - order should correspond with clients list

    Returns:
        data_types.BulkOperationResult
    """
    assert len(clients) == len(
        local_subnets
    ), "clients list length must equal local_subnets list length"

    invalid = []
    for index, client in enumerate(clients):
        private_ip = state.get_primary_private_ip(client)
        if not network_math.subnet_contains_ipv4(private_ip, local_subnets[index]):
            invalid.append("%s not in %s" % (private_ip, local_subnets[index]))

    if len(invalid):
        raise AssertionError(
            "Invalid subnets provided for clients: %s." % ",".join(invalid)
        )

    def _create_route(_client, subnet):
        return _client.routing.post_create_route(
            **{
                "cidr": subnet,
                "description": "Local subnet advertisement",
                "advertise": True,
                "gateway": "",
            }
        )

    bound_api_calls = [
        bind(_create_route, client, local_subnets[index])
        for index, client in enumerate(clients)
    ]

    return api_operations.__bulk_call_api(bound_api_calls)


def create_route_table(client: VNS3Client, routes, state={}):
    """Create routing policy

    Arguments:
        client {VNS3Client}
        routes {List[Route]} - [{
            "cidr": "str",
            "description": "str",
            "interface": "str",
            "gateway": "str",
            "tunnel": "int",
            "advertise": "bool",
            "metric": "int",
        }, ...]

    Keyword Arguments:
        state {dict} - State to format routes with. (can call client.state)

    Returns:
        Tuple[List[str], List[str]] - success, errors
    """
    successes = []
    errors = []
    Logger.debug(
        "Setting controller route table.",
        host=client.host_uri,
        route_count=len(routes),
    )

    _sub_vars = state or client.state
    for i, route_kwargs in enumerate(routes):
        skip = False
        for key, value in route_kwargs.items():
            _value, err = util.format_string(value, _sub_vars)
            if err:
                errors.append("Route key %s not formattable." % key)
                skip = True
            else:
                route_kwargs.update(**{key: _value})

        if skip:
            continue

        client.routing.post_create_route_if_not_exists(route_kwargs)
        successes.append("Route created: route=%s" % str(route_kwargs))

    if errors:
        raise CohesiveSDKException(",".join(errors))

    return successes, errors



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network"s addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3 import firewall_api
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import FirewallApiData


class TestFirewallApi(object):
    """FirewallApi unit test stubs"""

    def test_post_create_firewall_rule(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for post_create_firewall_rule
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/firewall/rules",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {
                    "status": "submitted",
                    "rule": "POSTROUTING_CUST -o eth0 -s 198.51.100.0/28 -j SNAT --to 10.0.1.120",
                    "token": "15798987631596_5280108744805298913050300048466684878015928855",
                }
            },
        )(firewall_api.post_create_firewall_rule)

    def test_delete_firewall_rule_by_position(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for delete_firewall_rule_by_position
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/firewall/rules/{position}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {
                    "status": "submitted",
                    "rule": "MACRO_CUST -o eth0 -s 198.51.100.0/28 -j MASQUERADE\n",
                    "position": 1,
                    "token": "15799073889568_958635609379530042894988535092666127141377814351",
                }
            },
        )(firewall_api.delete_firewall_rule_by_position)

    def test_delete_firewall_rule_by_rule(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for delete_firewall_rule_by_rule
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/firewall/rules",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {
                    "status": ":finished_ok, Matching rule found.",
                    "rule": "FORWARD_CUST -s 10.0.1.0/24 -d 10.0.3.0/24 -j ACCEPT",
                    "position": 4,
                }
            },
        )(firewall_api.delete_firewall_rule_by_rule)

    def test_delete_firewall_subgroup(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for delete_firewall_subgroup
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/firewall/rules/subgroup",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response": {"status": "finished_ok"}},
        )(firewall_api.delete_firewall_subgroup)

    def test_get_firewall_fw_sets(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for get_firewall_fw_sets
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/firewall/fwsets",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": ["PORTS_policy53 1194-1197", "PORTS_policy53 8080"]
            },
        )(firewall_api.get_firewall_fw_sets)

    def test_post_create_firewall_fw_set(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for post_create_firewall_fw_set
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/firewall/fwsets",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {
                    "status": "ok",
                    "rules": "PORTS_policy53 1194-1197\n PORTS_policy53 8080",
                }
            },
        )(firewall_api.post_create_firewall_fw_set)

    def test_delete_firewall_fw_set(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for delete_firewall_fw_set
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/firewall/fwsets",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response": {"status": "finished_ok"}},
        )(firewall_api.delete_firewall_fw_set)

    def test_get_firewall_rules(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_firewall_rules
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/firewall/rules",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": [
                    [
                        "POSTROUTING_CUST -o eth0 -s 198.51.100.0/28 -j SNAT --to 10.0.1.120\n",
                        0,
                    ],
                    ["MACRO_CUST -o eth0 -s 198.51.100.0/28 -j MASQUERADE\n", 1],
                    ["FORWARD_CUST -s 198.51.100.0/28 -j ACCEPT\n", 2],
                    ["FORWARD_CUST -d 198.51.100.0/28 -j ACCEPT\n", 3],
                    [
                        "PREROUTING_CUST -i eth0 -p tcp -s 0.0.0.0/0 --dport 44 -j DNAT --to 198.51.100.2:22\n",
                        4,
                    ],
                    ["FORWARD_CUST -s 10.0.1.0/24 -d 10.0.3.0/24 -j ACCEPT\n", 5],
                    ["FORWARD_CUST -d 10.0.1.0/24 -s 10.0.3.0/24 -j ACCEPT", 6],
                ]
            },
        )(firewall_api.get_firewall_rules)

    def test_get_firewall_rule_subgroups(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for get_firewall_rule_subgroups
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/firewall/rules/subgroup",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": [
                    ["INP_C_bensothergroup"],
                    ["INP_C_bensnewgroup -s 198.31.50.0/24 -j DROP"],
                ]
            },
        )(firewall_api.get_firewall_rule_subgroups)

    def test_post_create_firewall_subgroup(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for post_create_firewall_subgroup
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/firewall/rules/subgroup",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response": {
                    "status": "ok",
                    "rules": "INP_C_bensnewgro -s 198.31.50.0/24 -j DROP\n",
                }
            },
        )(firewall_api.post_create_firewall_subgroup)

    def test_put_reinitialize_fw_sets(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for put_reinitialize_fw_sets
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/firewall/fwsets",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={},
        )(firewall_api.put_reinitialize_fw_sets)

    def test_put_reinitialize_subgroups(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for put_reinitialize_subgroups
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/firewall/rules/subgroup",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={},
        )(firewall_api.put_reinitialize_subgroups)



class AccessApiData(object):
    TokenResponse = {"api_token": "f76a2cb3ca8107ba0aaa0394ca929cd622580938"}

    ExpireTokenResponse = {
        "response_type": "success",
        "response": {"message": "Successfully expired token"},
    }

    ApiKeysResponse = {
        "response_type": "success",
        "response": [
            {
                "id": 3,
                "name": "default",
                "enabled": True,
                "created_at": "2020-05-06T19:02:40.000Z",
                "default_key": False,
                "active_tokens": 1,
                "expired_tokens": 7,
                "last_access_time": "2020-05-12T22:43:13.000Z",
                "last_access_ip": "54.236.197.84",
            }
        ],
    }

    ExpireKeyTokens = {
        "response_type": "success",
        "response": {
            "message": "Invalidated 1 tokens",
            "name": "test",
            "id": 2,
            "enabled": True,
            "active_tokens": 0,
        },
    }

    NewApiKeyResponse = {
        "response_type": "success",
        "response": {
            "message": "Key created",
            "name": "api-created-new-again",
            "api_key": "4f00ac88739f00dbb8fd3b878a96d9e94aeae3b6a0b0048fd8427d5eee722b70c85c72de2f91331c18c90e90befd54e03b600efe1aa9c21e699256be87b9f9ef",
            "id": 4,
            "active_tokens": 0,
            "enabled": True,
        },
    }

    ApiKeyUpdatedResponse = {
        "response_type": "success",
        "response": {
            "message": "Key updated",
            "name": "test-updated",
            "id": 2,
            "enabled": True,
            "active_tokens": 1,
        },
    }


class AdminApiData(object):
    LdapSettingsResponse = {
        "response_type": "success",
        "response": {
            "ldap_host": None,
            "ldap_port": None,
            "ldap_ssl": None,
            "ldap_binddn": None,
            "ldap_bindpw": None,
        },
    }

    LdapUserSchemaResponse = {
        "response_type": "success",
        "response": {
            "ldap_user_base": "DN",
            "ldap_user_id_attribute": "1",
            "ldap_user_list_filter": "subtree",
        },
    }

    LdapGroupSchemaResponse = {
        "response_type": "success",
        "response": {
            "ldap_group_required": True,
            "ldap_group_base": "vns3admin",
            "ldap_group_id_attribute": "fact",
            "ldap_group_list_filter": None,
            "ldap_group_member_attribute": "again",
            "ldap_group_member_attr_format": "UserDN",
            "ldap_search_scope": "subtree",
        },
    }


class BackupsApiData(object):
    CreateBackupResponse = {
        "response_type": "success",
        "response": {
            "status": "Backup process queued",
            "uuid": "ce81bb5b-a917-49c7-8efd-d97d158d31fe",
        },
    }

    BackupJobStatusResponse = {
        "response_type": "success",
        "response": {
            "uuid": "ce81bb5b-a917-49c7-8efd-d97d158d31fe",
            "status": "Queued",
            "filename": "",
        },
    }


class CloudMonitoringApiData(object):
    CreateVirtualNetworkResponse = {
        "response_type": "success",
        "response": {"msg": "Virtual Network created", "id": 1},
    }

    CreateVns3TopologyResponse = {
        "response_type": "success",
        "response": {"msg": "VNS3 Topology created", "id": 1},
    }

    Vns3Topology = {
        "id": 1,
        "name": "Test VNS3 Topology",
        "virtual_network_name": "dev-env-network",
        "virtual_network_id": 1,
        "vns3_controllers": [{"id": 1, "name": "test-vns3-bp"}],
        "description": None,
    }

    Vns3TopologyDetail = {"response": Vns3Topology}

    Vns3TopologyList = {"response": [Vns3Topology]}

    VirtualNetwork = {
        "id": 1,
        "name": "dev-env-network",
        "description": "test environment",
        "created_at": "2020-05-14T14:27:16.000Z",
    }

    VirtualNetworkDetail = {"response": VirtualNetwork}

    VirtualNetworkList = {"response": [VirtualNetwork]}

    CloudVlan = {
        "id": 1,
        "name": "AWS VPC VLAN",
        "virtual_network_name": "dev-env-network",
        "virtual_network_id": 1,
        "description": "Test description for my testing topology turtles",
    }

    CloudVlanDetail = {"response": CloudVlan}

    CloudVlanList = {"response": [CloudVlan]}

    CloudVlanComponent = {
        "id": 1,
        "name": "dev-env-bplatta-vpc",
        "cloud_vlan_id": 1,
        "cloud_vlan": "AWS VPC VLAN",
        "cloud_cred_id": 1,
        "cloud_type": "EC2",
        "region": "us-east-1",
        "description": "My  vlan test",
    }

    CloudVlanComponentDetail = {"response": CloudVlanComponent}

    CloudVlanComponentList = {"response": [CloudVlanComponent]}

    Webhook1 = {
        "id": 1,
        "name": "bens-test-webhook",
        "validate_cert": False,
        "created_at": "2020-05-18T16:23:37.279Z",
        "updated_at": "2020-05-18T16:23:37.279Z",
        "body": "{}",
        "url": None,
        "custom_properties": [],
        "headers": [],
        "parameters": [],
        "events": ["tunnel_down", "tunnel_up"],
    }

    Webhook2 = {
        "id": 1,
        "name": "bens-2-webhook",
        "validate_cert": False,
        "created_at": "2020-05-18T16:23:37.279Z",
        "updated_at": "2020-05-18T16:23:37.279Z",
        "body": "{}",
        "url": None,
        "custom_properties": [{"name": "Prop1", "value": "val1"}],
        "headers": [],
        "parameters": [],
        "events": ["tunnel_down"],
    }

    WebhookDetail = {"response_type": "success", "response": Webhook1}

    WebhookListResponse = {"response_type": "success", "response": [Webhook1, Webhook2]}

    Alert = {
        "custom_properties": [],
        "events": ["test", "tunnel_down", "tunnel_up"],
        "enabled": True,
        "updated_at": "2020-05-18T16:42:19.407Z",
        "url": "https://hooks.slack.com/services/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",
        "webhook_id": 1,
        "id": 1,
        "created_at": "2020-05-18T16:42:19.407Z",
        "name": "BensAlert",
    }

    AlertDetail = {"response_type": "success", "response": Alert}

    AlertListResponse = {"response_type": "success", "response": [Alert]}


class SystemApiData(object):
    NTPHosts = {
        "response_type": "success",
        "response": {
            "0": "0.ubuntu.pool.ntp.org",
            "1": "1.ubuntu.pool.ntp.org",
            "2": "2.ubuntu.pool.ntp.org",
            "3": "3.ubuntu.pool.ntp.org",
            "4": "ntp.ubuntu.com",
        },
    }

    CredTypeDetails = {
        "name": "EC2",
        "code": "ec2",
        "fields": [
            {
                "name": "Use VNS3:ms IAM Role (Recommended Option)",
                "description": "Use VNS3:ms IAM Role to provide credentials",
                "required": True,
                "type": "BOOLEAN",
            },
            {
                "name": "Account ID",
                "description": "AWS Account ID (optional - VNS3:ms will attempt to fill if left blank)",
                "required": False,
                "type": "STRING",
            },
            {
                "name": "Access Key",
                "description": "AWS Access key",
                "required": True,
                "type": "STRING",
            },
            {
                "name": "Secret Key",
                "description": "AWS Secret key",
                "required": True,
                "type": "PASSWORD",
            },
            {
                "name": "GovCloud",
                "description": "These creds are for use in the EC2 GovCloud",
                "required": True,
                "type": "BOOLEAN",
            },
        ],
    }


class Vns3ManagementApiData(object):
    CreateVns3ControllerResponse = {
        "response_type": "success",
        "response": {"msg": "VNS3 Controller created", "id": 1},
    }

    Vns3SnapshotsList = {
        "response": {
            "snapshots": [
                {
                    "snapshot_id": 1,
                    "created_at": "2020-05-15T17:42:41.000Z",
                    "snapshot_name": "snapshot_20200515_1589564561_52.72.51.23",
                    "snapshot_size": 2072122,
                    "sha1_checksum": "c9cbcaca7d0e1996ae2411fde50f74881eeac542",
                    "available": True,
                    "status": "Stored locally",
                    "vns3_controller_id": 1,
                    "vns3_controller_name": "test-vns3-bp",
                }
            ],
            "failed_snapshots": [],
        }
    }

    ControllerReport = {
        "response_type": "success",
        "response": {
            "snapshot_date": "2020-05-15",
            "snapshot": [
                {
                    "controller_id": 1,
                    "controller_name": "test-vns3-bp",
                    "controller_version": "3.5-default",
                    "active": True,
                    "created_date": "2020-05-14T14:29:59+00:00",
                    "topology_id": 1,
                    "topology_name": "Test VNS3 Topology",
                    "virtual_network_id": 1,
                    "virtual_network_name": "dev-env-network",
                    "ha_backup_enabled": False,
                }
            ],
        },
    }

    Vns3Controller = {
        "id": 1,
        "name": "test-vns3-bp",
        "owner": "admin",
        "virtual_network_id": 1,
        "virtual_network": "dev-env-network",
        "vns3_topology_id": 1,
        "vns3_topology": "Test VNS3 Topology",
        "vns3_address": "10.0.1.34",
        "private_ip_address": None,
        "vns3_version": "3.5-default",
        "licensed": None,
        "active": True,
        "peered": None,
        "description": None,
        "controller_status": {
            "last_contact_time": "2020-05-15T17:47:25.000Z",
            "last_successful_contact_time": "2020-05-15T17:47:25.000Z",
            "last_contact_code": 200,
            "last_contact_result": "OK",
            "failed_contact_count": 0,
            "alerts_enabled": False,
        },
        "alerts_enabled": False,
    }

    Vns3ControllerDetail = {"response": Vns3Controller}

    Vns3ControllerList = {"response": [Vns3Controller]}

    Vns3ControllerHaDetail = {
        "response_type": "success",
        "response": {
            "ha_enabled": True,
            "ha_initialised": False,
            "ha_cloud_validated": True,
            "ms_sync_state": "Available",
            "ms_sync_fail_count": 0,
            "backup_active": False,
            "backup_sync_fail_count": 0,
            "ha_cloud_cred_id": 1,
            "primary_server_available": True,
            "backup_server_available": False,
            "ha_type": "cold",
            "ha_sync_processing": False,
            "ha_instance_id": "",
            "ha_image_id": "ami-12341234",
        },
    }


class UserApiData(object):

    CredsList = {
        "response_type": "success",
        "response": [
            {
                "id": 1,
                "name": "BensEc2Cred",
                "code": "ec2",
                "verified": True,
                "verification_message": "Cloud creds verified",
            }
        ],
    }



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3 import access_api
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import AccessApiData


class TestAccessApi(object):
    """AccessApi unit tests stubs"""

    def test_create_access_url(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for create_access_url
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/access/url",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlDetail,
        )(access_api.create_access_url)

    def test_create_api_token(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for create_api_token
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/access/token",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessTokenDetail,
        )(access_api.create_api_token)

    def test_delete_access_url(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_access_url
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/access/url/{access_url_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlDeleteResponse,
        )(access_api.delete_access_url)

    def test_delete_access_url_by_search(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for delete_access_url_by_search
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/access/url",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlDeleteResponse,
        )(access_api.delete_access_url_by_search)

    def test_delete_api_token(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_api_token
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/access/token/{token_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessTokenDeleteResponse,
        )(access_api.delete_api_token)

    def test_get_access_urls(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_access_urls
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/access/urls",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlListResponse,
        )(access_api.get_access_urls)

    def test_get_access_url(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_access_url
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/access/url/{access_url_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlDetail,
        )(access_api.get_access_url)

    def test_get_api_token(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_api_token
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/access/token/{token_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessTokenDetail,
        )(access_api.get_api_token)

    def test_get_api_tokens(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_api_tokens
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/access/tokens",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessTokenListResponse,
        )(access_api.get_api_tokens)

    def test_put_expire_access_url(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for put_expire_access_url
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/access/url/{access_url_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessUrlDetail,
        )(access_api.put_expire_access_url)

    def test_put_expire_api_token(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for put_expire_api_token
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/access/token/{token_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.AccessTokenDetail,
        )(access_api.put_expire_api_token)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3 import snapshots_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import SnapshotsApiData


class TestSnapshotsApi(object):
    """SnapshotsApi unit test stubs"""

    def test_delete_snapshot(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_snapshot

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/snapshots/{snapshot_name}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SnapshotsApiData.SnapshotsListResponse,
        )(snapshots_api.delete_snapshot)

    def test_get_download_snapshot(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for get_download_snapshot

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/snapshots/{snapshot_name}",
            rest_mocker,
            resp_content_type="application/octet-stream",
            mock_request_from_schema=True,
            mock_response="asdfasdfasdf",
        )(snapshots_api.get_download_snapshot)

    def test_get_snapshots(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_snapshots

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/snapshots",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SnapshotsApiData.SnapshotsListResponse,
        )(snapshots_api.get_snapshots)

    def test_post_create_snapshot(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for post_create_snapshot

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/snapshots",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SnapshotsApiData.SnapshotDetail,
        )(snapshots_api.post_create_snapshot)

    def test_put_import_snapshot(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for put_import_snapshot

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/snapshots/running_config",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SnapshotsApiData.SnapshotImportResponse,
        )(snapshots_api.put_import_snapshot)



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import cloud_monitoring_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3ms.stub_data import CloudMonitoringApiData


class TestMSMonitoringApi(object):
    """VNS3:ms Cloud Monitoring API unit tests"""

    def test_get_cloud_vlan_components(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_cloud_vlan_components
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/cloud_vlan_components",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CloudVlanComponentList,
        )(cloud_monitoring_api.get_cloud_vlan_components)

    def test_post_create_vlan_component(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_create_vlan_component
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/cloud_vlan_components",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"msg": "Cloud VLAN Component created", "id": 1},
            },
        )(cloud_monitoring_api.post_create_vlan_component)

    def test_get_cloud_vlan_component(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_cloud_vlan_component
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/cloud_vlan_components/{component_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CloudVlanComponentDetail,
        )(cloud_monitoring_api.get_cloud_vlan_component)

    def test_put_update_vlan_component(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_vlan_component
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/cloud_vlan_components/{component_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.put_update_vlan_component)

    def test_delete_vlan_component(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_vlan_component
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/cloud_vlan_components/{component_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.delete_vlan_component)

    def test_get_cloud_vlans(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_cloud_vlans
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/cloud_vlans",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CloudVlanList,
        )(cloud_monitoring_api.get_cloud_vlans)

    def test_post_create_cloud_vlan(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_create_cloud_vlan
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/cloud_vlans",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"msg": "Cloud VLAN created", "id": 1},
            },
        )(cloud_monitoring_api.post_create_cloud_vlan)

    def test_get_cloud_vlan(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_cloud_vlan
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/cloud_vlans/{vlan_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CloudVlanDetail,
        )(cloud_monitoring_api.get_cloud_vlan)

    def test_put_update_cloud_vlan(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_update_cloud_vlan
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/cloud_vlans/{vlan_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.put_update_cloud_vlan)

    def test_delete_cloud_vlan(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_cloud_vlan
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/cloud_vlans/{vlan_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "Deleted Cloud Vlan 1",
            },
        )(cloud_monitoring_api.delete_cloud_vlan)

    def test_get_virtual_networks(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_virtual_networks
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/virtual_networks",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.VirtualNetworkList,
        )(cloud_monitoring_api.get_virtual_networks)

    def test_post_create_virtual_network(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_create_virtual_network
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/virtual_networks",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CreateVirtualNetworkResponse,
        )(cloud_monitoring_api.post_create_virtual_network)

    def test_get_virtual_network(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_virtual_network
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/virtual_networks/{virtual_network_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.VirtualNetworkDetail,
        )(cloud_monitoring_api.get_virtual_network)

    def test_put_update_virtual_network(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_virtual_network
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/virtual_networks/{virtual_network_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "Updated Virtual Network",
            },
        )(cloud_monitoring_api.put_update_virtual_network)

    def test_delete_virtual_network(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_virtual_network
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/virtual_networks/{virtual_network_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "Deleted Virtual Network 1",
            },
        )(cloud_monitoring_api.delete_virtual_network)

    def test_get_export_virtual_networks(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_export_virtual_networks
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/virtual_networks/export",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response="imafileimafileimafileimafileimafileimafileimafileimafile",
        )(cloud_monitoring_api.get_export_virtual_networks)

    def test_post_import_virtual_networks(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_import_virtual_networks
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/virtual_networks/import",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.post_import_virtual_networks)

    def test_get_vns3_topologies(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_vns3_topologies
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_topologies",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.Vns3TopologyList,
        )(cloud_monitoring_api.get_vns3_topologies)

    def test_post_create_vns3_topology(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_create_vns3_topology
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/vns3_topologies",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.CreateVns3TopologyResponse,
        )(cloud_monitoring_api.post_create_vns3_topology)

    def test_get_vns3_topology(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_vns3_topology
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/vns3_topologies/{vns3_topology_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.Vns3TopologyDetail,
        )(cloud_monitoring_api.get_vns3_topology)

    def test_put_update_vns3_topology(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_vns3_topology
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/vns3_topologies/{vns3_topology_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.put_update_vns3_topology)

    def test_delete_vns3_topology(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_vns3_topology
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/vns3_topologies/{vns3_topology_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(cloud_monitoring_api.delete_vns3_topology)

    def test_get_webhooks(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_webhooks
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/webhooks",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.WebhookListResponse,
        )(cloud_monitoring_api.get_webhooks)

    def test_post_create_webhook(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_create_webhook
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/webhook",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.WebhookDetail,
        )(cloud_monitoring_api.post_create_webhook)

    def test_get_webhook(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_webhook
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.WebhookDetail,
        )(cloud_monitoring_api.get_webhook)

    def test_put_update_webhook(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_update_webhook
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.WebhookDetail,
        )(cloud_monitoring_api.put_update_webhook)

    def test_delete_webhook(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_webhook
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/webhook/{webhook_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.WebhookDetail,
        )(cloud_monitoring_api.delete_webhook)

    def test_get_alerts(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_alerts
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/alerts",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertListResponse,
        )(cloud_monitoring_api.get_alerts)

    def test_get_alert(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertDetail,
        )(cloud_monitoring_api.get_alert)

    def test_post_create_alert(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_create_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/alert",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertDetail,
        )(cloud_monitoring_api.post_create_alert)

    def test_put_update_alert(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_update_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertDetail,
        )(cloud_monitoring_api.put_update_alert)

    def test_delete_alert(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/alert/{alert_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertDetail,
        )(cloud_monitoring_api.delete_alert)

    def test_post_test_alert(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_test_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/alert/{alert_id}/test",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": "Alert sent successfully.",
            },
        )(cloud_monitoring_api.post_test_alert)

    def test_post_toggle_enable_alert(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_toggle_enable_alert
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/alert/{alert_id}/toggle_enabled",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=CloudMonitoringApiData.AlertDetail,
        )(cloud_monitoring_api.post_toggle_enable_alert)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from cohesivenet.api_builder import VersionRouter


def get_license(api_client, **kwargs):  # noqa: E501
    """get_license  # noqa: E501

    Get license details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_license(async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/license",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_license_upgrade(api_client, body=None, **kwargs):  # noqa: E501
    """put_license_upgrade  # noqa: E501

    Upload new license to controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_license_upgrade(body, async_req=True)

    :param async_req bool: execute request asynchronously
    :param body str: License file (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = body

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["text/plain"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/license/upgrade",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_set_license_parameters(
    api_client,
    subnet=None,
    managers=None,
    asns=None,
    clients=None,
    my_manager_vip=None,
    default=None,
    **kwargs
):  # noqa: E501
    """put_set_license_parameters  # noqa: E501

    Set and accept license parameters. Triggers reboot. Irreversible operation.  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_set_license_parameters(client, default=True, async_req=True)

    :param subnet str:
    :param managers str:
    :param asns str: space delimited ASNs
    :param clients str:
    :param my_manager_vip str:
    :param default bool: use default topology
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = [
        "subnet",
        "managers",
        "asns",
        "clients",
        "my_manager_vip",
        "default",
    ]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/license/parameters",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def upload_license(api_client, body=None, **kwargs):  # noqa: E501
    """upload_license  # noqa: E501

    License a VNS3 Controller to be a part of a specific topology. Must not be licensed already.  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.upload_license(client, body, async_req=True)

    :param body str: License file (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = body

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["text/plain"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/license",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


class LicensingApiRouter(VersionRouter):

    function_library = {
        "get_license": {"4.8.4-4.10.1": get_license},
        "put_license_upgrade": {"4.8.4-4.10.1": put_license_upgrade},
        "put_set_license_parameters": {"4.8.4-4.10.1": put_set_license_parameters},
        "upload_license": {"4.8.4-4.10.1": upload_license},
    }



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 provides complete control of your network's addresses, routes, rules and edge. Networking does  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from cohesivenet.api_builder import VersionRouter


def put_user_password(
    api_client, password=None, force_refresh=None, **kwargs
):  # noqa: E501
    """Update current user password  # noqa: E501

    Update current user password  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_user_password(password, async_req=True)

    :param VNS3Client api_client: (required)
    :param password str: New password (required)
    :param force_refresh bool: Force session refresh
    :param enabled bool: Enable/Disable API key
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["password", "force_refresh"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/password",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_user_credentials(api_client, cred_id=None, fields=True, **kwargs):  # noqa: E501
    """Get user credentials  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_user_credentials(async_req=True)

    :param VNS3Client api_client: (required)
    :param cred_id int: Filter by credential ID
    :param fields bool: Return user credential fields in response
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["cred_id", "fields"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/credentials",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_user_credential(
    api_client, name=None, code=None, fields=None, **kwargs
):  # noqa: E501
    """Create user credential  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_user_credential(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Name of new credential (required)
    :param code str: Credential type code (required)
    :param fields list[{key: str, value: str}]: Credential type code
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "code", "fields"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    # this is a little annoyance yet to be fixed in VNS3:ms (2.3.5)
    # expecting this field on ec2 codes
    body_params = {
        "fields": [{"key": "Use VNS3:ms IAM Role (Recommended Option)", "value": False}]
    }
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/credentials",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_ec2_credential(
    api_client, name=None, access_key=None, secret_key=None, gov_cloud=None, **kwargs
):  # noqa: E501
    """Create user credential  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_user_credential(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Name of new credential (required)
    :param access_key str: Access key (required)
    :param secret_key str: Secret key (required)
    :param gov_cloud bool: True if for Gov Cloud
    :param fields list[{key: str, value: str}]: Credential type code
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "access_key", "secret_key", "gov_cloud"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    fields = [
        {"key": "Access Key", "value": access_key},
        {"key": "Secret Key", "value": secret_key},
        {"key": "Use VNS3:ms IAM Role (Recommended Option)", "value": False},
        {"key": "GovCloud", "value": gov_cloud if gov_cloud is not None else False},
    ]

    body_params = {"name": name, "code": "ec2", "fields": fields}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/credentials",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_user_credential(
    api_client, credential_id, name=None, code=None, fields=None, **kwargs
):  # noqa: E501
    """Update user credential  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_user_credential(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param credential_id int: Credential ID (required)
    :param name str: Name of new credential
    :param code str: Credential type code
    :param fields list[{key: str, value: str}]: Credential type code
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "code", "fields"]

    collection_formats = {}

    path_params = {"credential_id": credential_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/credentials/{credential_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_user_credential(api_client, credential_id, **kwargs):  # noqa: E501
    """Delete user credential  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_user_credential(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param credential_id int: Credential ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"credential_id": credential_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth", "basicAuth"]  # noqa: E501

    return api_client.call_api(
        "/user/credentials/{credential_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


class UserApiRouter(VersionRouter):
    """User management endpoints for configuring credentials"""

    function_library = {
        "put_user_password": {"2.1.1-2.5.1": put_user_password},
        "get_user_credentials": {"2.1.1-2.5.1": get_user_credentials},
        "post_create_user_credential": {"2.1.1-2.5.1": post_create_user_credential},
        "post_create_ec2_credential": {"2.1.1-2.5.1": post_create_ec2_credential},
        "put_update_user_credential": {"2.1.1-2.5.1": put_update_user_credential},
        "delete_user_credential": {"2.1.1-2.5.1": delete_user_credential},
    }



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cohesivenet.api.vns3.bgp_api import BGPApiRouter as BGPApi
from cohesivenet.api.vns3.configuration_api import (
    ConfigurationApiRouter as ConfigurationApi,
)
from cohesivenet.api.vns3.firewall_api import FirewallApiRouter as FirewallApi
from cohesivenet.api.vns3.ipsec_api import IPsecApiRouter as IPsecApi
from cohesivenet.api.vns3.interfaces_api import InterfacesApiRouter as InterfacesApi
from cohesivenet.api.vns3.licensing_api import LicensingApiRouter as LicensingApi
from cohesivenet.api.vns3.monitoring_alerting_api import (
    MonitoringAlertingApiRouter as MonitoringAlertingApi,
)
from cohesivenet.api.vns3.network_edge_plugins_api import (
    NetworkEdgePluginsApiRouter as NetworkEdgePluginsApi,
)
from cohesivenet.api.vns3.overlay_network_api import (
    OverlayNetworkApiRouter as OverlayNetworkApi,
)
from cohesivenet.api.vns3.peering_api import PeeringApiRouter as PeeringApi
from cohesivenet.api.vns3.routing_api import RoutingApiRouter as RoutingApi
from cohesivenet.api.vns3.snapshots_api import SnapshotsApiRouter as SnapshotsApi
from cohesivenet.api.vns3.system_administration_api import (
    SystemAdministrationApiRouter as SystemAdministrationApi,
)
from cohesivenet.api.vns3.access_api import AccessApiRouter as AccessApi
